# camfi

[![Build Status](https://travis-ci.com/J-Wall/camfi.svg?branch=main)](https://travis-ci.com/J-Wall/camfi)
[![Documentation Status](https://readthedocs.org/projects/camfi/badge/?version=latest)](https://camfi.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/309541834.svg)](https://zenodo.org/badge/latestdoi/309541834)

**C**amera-based **A**nalysis and **M**onitoring of **F**lying **I**nsects

Camfi is a method for the long-term non-invasive monitoring of the activity and
abundance of low-flying insects using inexpensive wildlife cameras. It provides
utilities for measuring the wingbeat frequency of insects in still images, based
on the motion blurs drawn on the image sensor by the insect moving through the
air. For large-scale monitoring projects, camfi enables automatic annotation of
flying insects using the Mask R-CNN framework.

Please see the [docs](https://camfi.readthedocs.io/en/latest/index.html) for
installation and usage instructions.
